@@ -14,12 +14,13 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with python-alogger  If not, see <http://www.gnu.org/licenses/>.
+from __future__ import absolute_import
+from __future__ import unicode_literals
 
 import unittest
 from .base import Base
 
 
-@unittest.skip("Need slurm log file")
 class TestSlurm(Base, unittest.TestCase):
     file_prefix = "slurm"
-    log_type = "slurm"
+    log_type = "SLURM"
