@@ -14,6 +14,8 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with python-alogger  If not, see <http://www.gnu.org/licenses/>.
+from __future__ import absolute_import
+from __future__ import unicode_literals
 
 import unittest
 from .base import Base
@@ -21,5 +23,5 @@ from .base import Base
 
 @unittest.skip("Win HPC support is broken")
 class TestWinHPC(Base, unittest.TestCase):
-    file_prefix = "slurm"
-    log_type = "slurm"
+    file_prefix = "winhpc"
+    log_type = "WINHPC"
